==> octave_7.3.0.orig.tar.xz: octave-7.3.0/liboctave/util/unwind-prot.cc <==
////////////////////////////////////////////////////////////////////////
//
// Copyright (C) 1993-2022 The Octave Project Developers
//
// See the file COPYRIGHT.md in the top-level directory of this
// distribution or <https://octave.org/copyright/>.
//
// This file is part of Octave.
//
// Octave is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Octave is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Octave; see the file COPYING.  If not, see
// <https://www.gnu.org/licenses/>.
//
////////////////////////////////////////////////////////////////////////

#if defined (HAVE_CONFIG_H)
#  include "config.h"
#endif

#include "lo-error.h"
#include "unwind-prot.h"

namespace octave
{
  void
  unwind_protect_safe::warn_unhandled_exception (void) const
  {
    (*current_liboctave_warning_handler)
      ("unhandled exception in unwind_protect_safe handler.  "
       "It is a bug in Octave for this to happen.  "
       "Please help improve Octave by reporting it.");
  }

  void
  unwind_action_safe::warn_unhandled_exception (void) const
  {
    (*current_liboctave_warning_handler)
      ("unhandled exception in unwind_action_safe handler.  "
       "It is a bug in Octave for this to happen.  "
       "Please help improve Octave by reporting it.");
  }
}

==> octave_9.4.0.orig.tar.xz: octave-9.4.0/liboctave/util/unwind-prot.cc <==
////////////////////////////////////////////////////////////////////////
//
// Copyright (C) 1993-2024 The Octave Project Developers
//
// See the file COPYRIGHT.md in the top-level directory of this
// distribution or <https://octave.org/copyright/>.
//
// This file is part of Octave.
//
// Octave is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Octave is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Octave; see the file COPYING.  If not, see
// <https://www.gnu.org/licenses/>.
//
////////////////////////////////////////////////////////////////////////

#if defined (HAVE_CONFIG_H)
#  include "config.h"
#endif

#include "lo-error.h"
#include "unwind-prot.h"

OCTAVE_BEGIN_NAMESPACE(octave)

void
unwind_protect_safe::warn_unhandled_exception () const
{
  (*current_liboctave_warning_handler)
    ("unhandled exception in unwind_protect_safe handler.  "
     "It is a bug in Octave for this to happen.  "
     "Please help improve Octave by reporting it.");
}

void
unwind_action_safe::warn_unhandled_exception () const
{
  (*current_liboctave_warning_handler)
    ("unhandled exception in unwind_action_safe handler.  "
     "It is a bug in Octave for this to happen.  "
     "Please help improve Octave by reporting it.");
}

OCTAVE_END_NAMESPACE(octave)
